@@ -33,6 +33,7 @@
 #include <QPixmap>
 #include <QSettings>
 #include <QGSettings>
+#include <QVariant>
 
 #include <DHiDPIHelper>
 #include <DGuiApplicationHelper>
@@ -58,7 +59,12 @@ static QMap<int, AppsListModel::AppCategory> CateGoryMap {
     { 10, AppsListModel::Others      }
 };
 
+const QStringList sysHideUseProxyPackages();
+const QStringList sysCantUseProxyPackages();
+
 static QGSettings *gSetting = SettingsPtr("com.deepin.dde.launcher", "/com/deepin/dde/launcher/");
+static QStringList hideUseProxyPackages(sysHideUseProxyPackages());
+static QStringList cantUseProxyPackages(sysCantUseProxyPackages());
 
 const QStringList sysHideOpenPackages()
 {
@@ -123,9 +129,30 @@ const QStringList sysHideUseProxyPackages()
         hideUseProxy_list << gSetting->get("apps-hide-use-proxy-list").toStringList();
     }
 
+    QObject::connect(gSetting, &QGSettings::changed, [ & ](const QString &key) {
+        if (!key.compare("appsHideUseProxyList"))
+            hideUseProxyPackages = sysHideUseProxyPackages();
+    });
+
     return hideUseProxy_list;
 }
 
+const QStringList sysCantUseProxyPackages()
+{
+    QStringList cantUseProxy_list;
+    //从gschema读取隐藏使用代理功能软件列表
+    if (gSetting && gSetting->keys().contains("appsCanNotUseProxyList")) {
+        cantUseProxy_list << gSetting->get("apps-can-not-use-proxy-list").toStringList();
+    }
+
+    QObject::connect(gSetting, &QGSettings::changed, [ & ](const QString &key) {
+        if (!key.compare("appsCanNotUseProxyList"))
+            cantUseProxyPackages = sysCantUseProxyPackages();
+    });
+
+    return cantUseProxy_list;
+}
+
 const QStringList sysCantOpenPackages()
 {
     QStringList cantOpen_list;
@@ -194,7 +221,6 @@ AppsListModel::AppsListModel(const AppCategory &category, QObject *parent)
     , m_hideSendToDockPackages(sysHideSendToDockPackages())
     , m_hideStartUpPackages(sysHideStartUpPackages())
     , m_hideUninstallPackages(sysHideUninstallPackages())
-    , m_hideUseProxyPackages(sysHideUseProxyPackages())
     , m_cantOpenPackages(sysCantOpenPackages())
     , m_cantSendToDesktopPackages(sysCantSendToDesktopPackages())
     , m_cantSendToDockPackages(sysCantSendToDockPackages())
@@ -240,12 +266,6 @@ void AppsListModel::setDragDropIndex(const QModelIndex &index)
     emit QAbstractListModel::dataChanged(m_dragStartIndex, index);
 }
 
-///
-/// \brief AppsListModel::dropInsert restore item from appsManager stash list
-/// \param appKey item token in stash list
-/// \param pos insert position, if pos is negetive, insert into front
-///
-///
 /**
  * @brief AppsListModel::dropInsert 插入拖拽后的item
  * @param appKey item应用对应的key值
@@ -432,7 +452,7 @@ QVariant AppsListModel::data(const QModelIndex &index, int role) const
         return QVariant();
 
     int start = nFixCount * m_pageIndex;
-    const ItemInfo &itemInfo = m_appsManager->appsInfoListIndex(m_category,start + index.row());
+    const ItemInfo &itemInfo = m_appsManager->appsInfoListIndex(m_category, start + index.row());
 
     switch (role) {
     case AppRawItemInfoRole:
@@ -474,7 +494,7 @@ QVariant AppsListModel::data(const QModelIndex &index, int role) const
     case AppIconRole:
         return m_appsManager->appIcon(itemInfo, m_calcUtil->appIconSize().width());
     case AppDialogIconRole:
-        return m_appsManager->appIcon(itemInfo, 36 * qApp->devicePixelRatio());
+        return m_appsManager->appIcon(itemInfo, 36);
     case AppDragIconRole:
         return m_appsManager->appIcon(itemInfo, m_calcUtil->appIconSize().width() * 1.2);
     case AppListIconRole: {
@@ -509,7 +529,7 @@ QVariant AppsListModel::data(const QModelIndex &index, int role) const
         return (m_actionSettings && !m_actionSettings->get("uninstall").toBool()) || m_hideUninstallPackages.contains(itemInfo.m_key);
     case AppHideUseProxyRole:
     {
-        bool hideUse = ((m_actionSettings && !m_actionSettings->get("use-proxy").toBool()) || m_hideUseProxyPackages.contains(itemInfo.m_key));
+        bool hideUse = ((m_actionSettings && !m_actionSettings->get("use-proxy").toBool()) || hideUseProxyPackages.contains(itemInfo.m_key));
         return DSysInfo::isCommunityEdition() ? hideUse : (!QFile::exists(ChainsProxy_path) || hideUse);
     }
     case AppCanOpenRole:
@@ -520,6 +540,8 @@ QVariant AppsListModel::data(const QModelIndex &index, int role) const
         return !m_cantSendToDockPackages.contains(itemInfo.m_key);
     case AppCanStartUpRole:
         return !m_cantStartUpPackages.contains(itemInfo.m_key);
+    case AppCanOpenProxyRole:
+        return !cantUseProxyPackages.contains(itemInfo.m_key);
     default:;
     }
 
