@@ -22,6 +22,16 @@
 #include "windowedframe.h"
 #include "widgets/hseparator.h"
 #include "global_util/util.h"
+#include "dbusdockinterface.h"
+#include "constants.h"
+#include "iconcachemanager.h"
+
+#include <DWindowManagerHelper>
+#include <DForeignWindow>
+#include <DGuiApplicationHelper>
+#include <DDBusSender>
+#include <DDialog>
+#include <QLabel>
 
 #include <QApplication>
 #include <QHBoxLayout>
@@ -35,13 +45,9 @@
 #include <QEvent>
 #include <QTimer>
 #include <QDebug>
+#include <QDBusConnection>
 
 #include <qpa/qplatformwindow.h>
-#include <DWindowManagerHelper>
-#include <DForeignWindow>
-#include <DGuiApplicationHelper>
-#include <DDBusSender>
-#include <DDialog>
 
 #define DOCK_TOP        0
 #define DOCK_RIGHT      1
@@ -53,6 +59,8 @@
 
 DGUI_USE_NAMESPACE
 
+using namespace DLauncher;
+
 extern const QPoint widgetRelativeOffset(const QWidget *const self, const QWidget *w);
 
 inline const QPoint scaledPosition(const QPoint &xpos)
@@ -79,33 +87,38 @@ inline const QPoint scaledPosition(const QPoint &xpos)
 WindowedFrame::WindowedFrame(QWidget *parent)
     : DBlurEffectWidget(parent)
     , m_dockInter(new DBusDock(this))
-    , m_menuWorker(new MenuWorker)
+    , m_menuWorker(new MenuWorker(this))
     , m_eventFilter(new SharedEventFilter(this))
     , m_windowHandle(this, this)
     , m_wmHelper(DWindowManagerHelper::instance())
     , m_maskBg(new QWidget(this))
     , m_appsManager(AppsManager::instance())
-    , m_appsView(new AppListView)
-    , m_appsModel(new AppsListModel(AppsListModel::Custom))
-    , m_searchModel(new AppsListModel(AppsListModel::Search))
-    , m_leftBar(new MiniFrameRightBar)
-    , m_switchBtn(new MiniFrameSwitchBtn)
+    , m_appsView(new AppListView(this))
+    , m_appsModel(new AppsListModel(AppsListModel::Custom, this))
+    , m_searchModel(new AppsListModel(AppsListModel::Search, this))
+    , m_leftBar(new MiniFrameRightBar(this))
+    , m_switchBtn(new MiniFrameSwitchBtn(this))
     , m_tipsLabel(new QLabel(this))
-    , m_delayHideTimer(new QTimer)
-    , m_autoScrollTimer(new QTimer)
+    , m_delayHideTimer(new QTimer(this))
+    , m_autoScrollTimer(new QTimer(this))
     , m_appearanceInter(new Appearance("com.deepin.daemon.Appearance", "/com/deepin/daemon/Appearance", QDBusConnection::sessionBus(), this))
     , m_displayMode(All)
     , m_calcUtil(CalculateUtil::instance())
     , m_focusPos(Applist)
     , m_modeToggleBtn(new ModeToggleButton(this))
-    , m_searcherEdit(new DSearchEdit)
+    , m_searcherEdit(new DSearchEdit(this))
     , m_enterSearchEdit(false)
+    , m_curScreen(m_appsManager->currentScreen())
 {
+    if (!getDConfigValue("enable-full-screen-mode", true).toBool())
+        m_modeToggleBtn->hide();
+
     m_searcherEdit->setAccessibleName("searcherEdit");
     m_maskBg->setAccessibleName("MaskBg");
     m_switchBtn->setAccessibleName("switchBtn");
     m_modeToggleBtn->setAccessibleName("modeToggleBtn");
     m_searcherEdit->setAccessibleName("WindowedSearcherEdit");
+    m_tipsLabel->setAccessibleName("tipsLabel");
 
     setMaskColor(DBlurEffectWidget::AutoColor);
     setBlendMode(DBlurEffectWidget::InWindowBlend);
@@ -120,7 +133,7 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     m_windowHandle.setTranslucentBackground(false);
 
     m_appsView->setModel(m_appsModel);
-    m_appsView->setItemDelegate(new AppListDelegate);
+    m_appsView->setItemDelegate(new AppListDelegate(this));
 
     m_appsView->installEventFilter(m_eventFilter);
     m_switchBtn->installEventFilter(m_eventFilter);
@@ -167,7 +180,7 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     containLayout->addLayout(appsLayout);
     containLayout->addLayout(switchLayout);
 
-    m_rightWidget = new QWidget;
+    m_rightWidget = new QWidget(this);
     m_rightWidget->setContentsMargins(0, 0, 0, 0);
     m_rightWidget->setLayout(containLayout);
     m_rightWidget->setFixedWidth(320);
@@ -185,6 +198,11 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     setFixedHeight(538);
     setObjectName("MiniFrame");
 
+    create();
+    if (windowHandle()) {
+        windowHandle()->setProperty("_d_dwayland_window-type", "launcher");
+    }
+
     initAnchoredCornor();
     installEventFilter(m_eventFilter);
 
@@ -204,7 +222,6 @@ WindowedFrame::WindowedFrame(QWidget *parent)
             m_autoScrollTimer->start();
     });
 
-    connect(m_leftBar, &MiniFrameRightBar::modeToggleBtnClicked, this, &WindowedFrame::onToggleFullScreen);
     connect(m_leftBar, &MiniFrameRightBar::requestFrameHide, this, &WindowedFrame::hideLauncher, Qt::QueuedConnection);
 
     connect(m_wmHelper, &DWindowManagerHelper::hasCompositeChanged, this, &WindowedFrame::onWMCompositeChanged);
@@ -229,10 +246,17 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     connect(m_delayHideTimer, &QTimer::timeout, this, &WindowedFrame::prepareHideLauncher, Qt::QueuedConnection);
 
     connect(m_appearanceInter, &Appearance::OpacityChanged, this, &WindowedFrame::onOpacityChanged);
-    connect(m_modeToggleBtn, &DToolButton::clicked, m_leftBar, &MiniFrameRightBar::modeToggleBtnClicked);
+    connect(m_modeToggleBtn, &DToolButton::clicked, this, &WindowedFrame::onToggleFullScreen);
+
     QTimer::singleShot(1, this, &WindowedFrame::onWMCompositeChanged);
     onOpacityChanged(m_appearanceInter->opacity());
 
+    connect(m_curScreen, &QScreen::geometryChanged, this, &WindowedFrame::onScreenInfoChange);
+    connect(m_curScreen, &QScreen::orientationChanged, this, &WindowedFrame::onScreenInfoChange);
+    connect(qApp, &QApplication::primaryScreenChanged, this, &WindowedFrame::onScreenInfoChange);
+
+    connect(this, &WindowedFrame::visibleChanged, this, &WindowedFrame::onHideMenu);
+
     // 状态切换
     m_switchBtn->updateStatus(All);
     m_modeToggleBtn->setIconSize(QSize(32,32));
@@ -245,34 +269,30 @@ WindowedFrame::WindowedFrame(QWidget *parent)
     m_maskBg->setFixedSize(size());
 }
 
-WindowedFrame::~WindowedFrame()
-{
-    m_eventFilter->deleteLater();
-}
-
 void WindowedFrame::showLauncher()
 {
-    if (visible() || m_delayHideTimer->isActive())
+    if (m_delayHideTimer->isActive())
         return;
 
     qApp->processEvents();
-	activateWindow();
+    activateWindow();
     setFocus(Qt::ActiveWindowFocusReason);
 
-    // force refresh
-    if (!m_appsManager->isVaild()) {
+    // 初始化所有应用数据
+    if (!m_appsManager->isVaild())
         m_appsManager->refreshAllList();
-    }
 
     m_appsView->setCurrentIndex(QModelIndex());
 
-    adjustSize(); // right widget need calculate width based on font
+    adjustSize();
+
+    // 启动器跟随任务栏位置
     adjustPosition();
     m_cornerPath = getCornerPath(m_anchoredCornor);
     m_windowHandle.setClipPath(m_cornerPath);
-    show();
 
-    connect(m_dockInter, &DBusDock::FrontendRectChanged, this, &WindowedFrame::hideLauncher);
+    if (IconCacheManager::iconLoadState())
+        show();
 }
 
 void WindowedFrame::hideLauncher()
@@ -283,8 +303,6 @@ void WindowedFrame::hideLauncher()
 
     m_delayHideTimer->stop();
 
-    disconnect(m_dockInter, &DBusDock::FrontendRectChanged, this, &WindowedFrame::hideLauncher);
-
     m_searcherEdit->lineEdit()->clear();
     m_searcherEdit->clearEdit();
     // clean all state
@@ -298,6 +316,10 @@ bool WindowedFrame::visible()
     return isVisible();
 }
 
+/**
+ * @brief WindowedFrame::moveCurrentSelectApp 处理键盘事件
+ * @param key 键盘按键名
+ */
 void WindowedFrame::moveCurrentSelectApp(const int key)
 {
     if(Qt::Key_Undo == key) {
@@ -484,21 +506,21 @@ void WindowedFrame::appendToSearchEdit(const char ch)
 
 void WindowedFrame::launchCurrentApp()
 {
+    const QModelIndex currentIdx = m_appsView->currentIndex();
+
     if (m_focusPos == Computer || m_focusPos == Setting || m_focusPos == Power) {
         m_leftBar->execCurrent();
         return;
-    } else if (m_focusPos == RightBottom) {
+    } else if (m_focusPos == RightBottom && !currentIdx.isValid()) {
         m_switchBtn->click();
         return;
     }
 
     if (m_displayMode == Category && m_appsModel->category() == AppsListModel::Category) {
-        switchToCategory(m_appsView->currentIndex());
+        switchToCategory(currentIdx);
         return;
     }
 
-    const QModelIndex currentIdx = m_appsView->currentIndex();
-
     if (currentIdx.isValid() && currentIdx.model() == m_appsView->model()) {
         m_appsManager->launchApp(currentIdx);
     } else {
@@ -523,13 +545,38 @@ void WindowedFrame::uninstallApp(const QModelIndex &context)
 
     UNINSTALL_DIALOG_SHOWN = true;
     DTK_WIDGET_NAMESPACE::DDialog unInstallDialog;
+    unInstallDialog.setAccessibleName("unInstallDialog");
     unInstallDialog.setWindowFlags(Qt::Dialog | unInstallDialog.windowFlags());
     unInstallDialog.setWindowModality(Qt::WindowModal);
 
     const QString appKey = context.data(AppsListModel::AppKeyRole).toString();
     unInstallDialog.setTitle(QString(tr("Are you sure you want to uninstall it?")));
-    QPixmap appIcon = context.data(AppsListModel::AppDialogIconRole).value<QPixmap>();
-    unInstallDialog.setIcon(appIcon);
+
+    QPixmap pixmap = context.data(AppsListModel::AppDialogIconRole).value<QPixmap>();
+
+    int size = (pixmap.size() / qApp->devicePixelRatio()).width();
+    ItemInfo item = context.data(AppsListModel::AppRawItemInfoRole).value<ItemInfo>();
+
+    QPair<QString, int> tmpKey { cacheKey(item, CacheType::ImageType), size};
+
+    // 命令行安装应用后，卸载应用的确认弹框偶现左上角图标呈齿轮的情况
+    QPixmap appIcon;
+    if (IconCacheManager::existInCache(tmpKey)) {
+        IconCacheManager::getPixFromCache(tmpKey, appIcon);
+        unInstallDialog.setIcon(appIcon);
+    } else {
+        static int tryNum = 0;
+        UNINSTALL_DIALOG_SHOWN = false;
+        ++tryNum;
+        if (tryNum <= 5) {
+            QTimer::singleShot(100, this, [ = ]() { uninstallApp(context); });
+            return;
+        } else {
+            QIcon icon = QIcon(":/widgets/images/application-x-desktop.svg");
+            appIcon = icon.pixmap(QSize(size, size));
+            unInstallDialog.setIcon(appIcon);
+        }
+    }
 
     QStringList buttons;
     buttons << tr("Cancel") << tr("Confirm");
@@ -551,18 +598,13 @@ void WindowedFrame::uninstallApp(const QModelIndex &context)
     UNINSTALL_DIALOG_SHOWN = false;
 }
 
-bool WindowedFrame::windowDeactiveEvent()
-{
-    // don't need
-//    if (isVisible() && !m_menuWorker->isMenuShown() && !m_delayHideTimer->isActive()) {
-//        m_delayHideTimer->start();
-//    }
-
-    return false;
-}
-
+/**分类模式下，进入到某一分类目录的处理
+ * @brief WindowedFrame::switchToCategory
+ * @param index 当前视图的模型索引
+ */
 void WindowedFrame::switchToCategory(const QModelIndex &index)
 {
+    m_focusPos = Applist;
     m_appsView->setModel(m_appsModel);
     m_appsView->setCurrentIndex(QModelIndex());
     m_appsModel->setCategory(index.data(AppsListModel::AppCategoryRole).value<AppsListModel::AppCategory>());
@@ -625,11 +667,12 @@ void WindowedFrame::resetWidgetStyle()
     m_tipsLabel->setPalette(palette);
 
     palette = m_maskBg->palette();
-    if( DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType){
-        palette.setColor(QPalette::Background, QColor(0,0,0,0.3*255));
-    }else{
-        palette.setColor(QPalette::Background, QColor(255,255,255,0.3*255));
-    }
+
+    if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType)
+        palette.setColor(QPalette::Background, QColor(0, 0, 0, 0.3 * 255));
+    else
+        palette.setColor(QPalette::Background, QColor(255, 255, 255, 0.3 * 255));
+
     m_maskBg->setPalette(palette);
 }
 
@@ -715,9 +758,11 @@ QVariant WindowedFrame::inputMethodQuery(Qt::InputMethodQuery prop) const
     return QWidget::inputMethodQuery(prop);
 }
 
-void WindowedFrame::regionMonitorPoint(const QPoint &point)
+void WindowedFrame::regionMonitorPoint(const QPoint &point, int flag)
 {
+    Q_UNUSED(flag);
     auto windowList = DWindowManagerHelper::instance()->currentWorkspaceWindows();
+
     for (auto window : windowList) {
         if (window->handle()->geometry().contains(point)) {
             if (window->wmClass() == "onboard") return;
@@ -728,6 +773,7 @@ void WindowedFrame::regionMonitorPoint(const QPoint &point)
         if (m_menuWorker->isMenuShown() && m_menuWorker->menuGeometry().contains(point)) {
             return;
         }
+
         hideLauncher();
     }
 }
@@ -749,8 +795,14 @@ bool WindowedFrame::eventFilter(QObject *watched, QEvent *event)
         }
     }
 
-    if (watched == m_searcherEdit && event->type() == QEvent::Enter) {
+    if (watched == m_searcherEdit && event->type() == QEvent::Enter)
         m_enterSearchEdit = true;
+
+    // 清除行编辑器的焦点(已被dtk封装了)
+    if (event->type() == QEvent::KeyPress && m_searcherEdit->lineEdit()->hasFocus()) {
+        QKeyEvent *keyPress = static_cast<QKeyEvent *>(event);
+        if (keyPress && keyPress->key() == Qt::Key_Tab)
+            m_searcherEdit->lineEdit()->clearFocus();
     }
 
     return QWidget::eventFilter(watched, event);
@@ -762,7 +814,7 @@ void WindowedFrame::resizeEvent(QResizeEvent *event)
         initAnchoredCornor();
         m_cornerPath = getCornerPath(m_anchoredCornor);
         m_windowHandle.setClipPath(m_cornerPath);
-        //event.size() 第一次启动有时候会很大或者很小的负数,直接用固定的size
+        // event.size() 第一次启动有时候会很大或者很小的负数,直接用固定的size
         m_maskBg->setFixedSize(size());
         m_maskBg->move(0,0);
     });
@@ -798,31 +850,27 @@ void WindowedFrame::initAnchoredCornor()
 
 void WindowedFrame::adjustPosition()
 {
-    const int dockPos = m_dockInter->position();
     QRect r =  m_dockInter->frontendRect();
     QRect dockRect = QRect(scaledPosition(r.topLeft()),scaledPosition(r.bottomRight()));
 
-    const auto &s = size();
+    // 启动器高效模式和时尚模式与任务栏的间隙不同
     int dockSpacing = 0;
-    if (m_dockInter->displayMode() == DOCK_FASHION) {
+    if (m_dockInter->displayMode() == DOCK_FASHION)
         dockSpacing = 8;
-    }
 
     QPoint p;
-
-    // The position of the launcher is different in different modes
-    switch (dockPos) {
+    switch (m_dockInter->position()) {
     case DOCK_TOP:
         p = QPoint(dockRect.left(), dockRect.bottom() + dockSpacing + 1);
         break;
     case DOCK_BOTTOM:
-        p = QPoint(dockRect.left(), dockRect.top() - s.height() - dockSpacing);
+        p = QPoint(dockRect.left(), dockRect.top() - height() - dockSpacing);
         break;
     case DOCK_LEFT:
         p = QPoint(dockRect.right() + dockSpacing + 1, dockRect.top());
         break;
     case DOCK_RIGHT:
-        p = QPoint(dockRect.left() - s.width() - dockSpacing, dockRect.top());
+        p = QPoint(dockRect.left() - width() - dockSpacing, dockRect.top());
         break;
     default:
         Q_UNREACHABLE_IMPL();
@@ -834,18 +882,19 @@ void WindowedFrame::adjustPosition()
 
 void WindowedFrame::onToggleFullScreen()
 {
-    //后台没有启动,切换全屏会造成后台默认数据和前台数据不统一,造成显示问题
-    if(!m_appsManager->appNums(AppsListModel::All)) {
+    // 后台没有启动,切换全屏会造成后台默认数据和前台数据不统一,造成显示问题
+    if (!m_appsManager->appNums(AppsListModel::All))
         return;
-    }
 
-    AppListDelegate * delegate = static_cast<AppListDelegate *>(m_appsView->itemDelegate());
-    if (delegate) {
+    // 切换到全屏就不绘制小窗口列表中的item
+    AppListDelegate *delegate = static_cast<AppListDelegate *>(m_appsView->itemDelegate());
+    if (delegate)
         delegate->setActived(false);
-    }
 
+    // 全屏状态标识
     m_calcUtil->setFullScreen(true);
 
+    // 同步本地当前是全屏的状态
     DDBusSender()
     .service("com.deepin.dde.daemon.Launcher")
     .interface("com.deepin.dde.daemon.Launcher")
@@ -859,6 +908,8 @@ void WindowedFrame::onSwitchBtnClicked()
     if (m_displayMode == All) {
         m_appsModel->setCategory(AppsListModel::Category);
         m_displayMode = Category;
+        m_appsView->setCurrentIndex(QModelIndex());
+        m_focusPos = RightBottom;
     } else if (m_displayMode == Category && m_appsModel->category() != AppsListModel::Category) {
         m_appsModel->setCategory(AppsListModel::Category);
     } else {
@@ -876,11 +927,11 @@ void WindowedFrame::onSwitchBtnClicked()
 
 void WindowedFrame::onWMCompositeChanged()
 {
-    if (m_wmHelper->hasComposite()) {
+    if (m_wmHelper->hasComposite())
         m_radius = 18;
-    } else {
+    else
         m_radius = 0;
-    }
+
     initAnchoredCornor();
     m_cornerPath = getCornerPath(m_anchoredCornor);
     m_windowHandle.setClipPath(m_cornerPath);
@@ -892,6 +943,7 @@ void WindowedFrame::searchText(const QString &text)
         m_appsView->setModel(m_appsModel);
         hideTips();
         m_switchBtn->setVisible(true);
+        m_displayMode = Category;
     } else {
         m_switchBtn->setVisible(false);
         if (m_appsView->model() != m_searchModel) {
@@ -901,9 +953,8 @@ void WindowedFrame::searchText(const QString &text)
         }
         auto temp = text;
         m_appsManager->searchApp(temp.replace(" ",""));
+        m_displayMode = All;
     }
-
-    m_displayMode = All;
 }
 
 void WindowedFrame::showTips(const QString &text)
@@ -926,13 +977,11 @@ void WindowedFrame::hideTips()
 
 void WindowedFrame::prepareHideLauncher()
 {
-    if (!visible()) {
+    if (!visible())
         return;
-    }
 
-    if (geometry().contains(QCursor::pos()) || m_menuWorker->menuGeometry().contains(QCursor::pos())) {
+    if (geometry().contains(QCursor::pos()) || m_menuWorker->menuGeometry().contains(QCursor::pos()))
         return activateWindow(); /* get focus back */
-    }
 
     hideLauncher();
 }
@@ -958,6 +1007,59 @@ void WindowedFrame::onOpacityChanged(const double value)
     setMaskAlpha(value * 255);
 }
 
+void WindowedFrame::onScreenInfoChange()
+{
+    m_curScreen->disconnect();
+    m_curScreen = m_appsManager->currentScreen();
+
+    adjustSize();
+    updatePosition();
+    m_cornerPath = getCornerPath(m_anchoredCornor);
+    m_windowHandle.setClipPath(m_cornerPath);
+
+    connect(m_curScreen, &QScreen::geometryChanged, this, &WindowedFrame::onScreenInfoChange);
+    connect(m_curScreen, &QScreen::orientationChanged, this, &WindowedFrame::onScreenInfoChange);
+}
+
+void WindowedFrame::updatePosition()
+{
+   // 该接口获取数据是翻转后的数据
+   DBusDockInterface inter;
+   QRect dockGeo = inter.geometry();
+   QRect dockRect = QRect(scaledPosition(dockGeo.topLeft()),scaledPosition(dockGeo.bottomRight()));
+
+    int dockSpacing = 0;
+    if (m_dockInter->displayMode() == DOCK_FASHION)
+        dockSpacing = 8;
+
+    QPoint p;
+    switch (m_dockInter->position()) {
+    case DOCK_TOP:
+        p = QPoint(dockRect.left(), dockRect.bottom() + dockSpacing + 1);
+        break;
+    case DOCK_BOTTOM:
+        p = QPoint(dockRect.left(), dockRect.top() - height() - dockSpacing);
+        break;
+    case DOCK_LEFT:
+        p = QPoint(dockRect.right() + dockSpacing + 1, dockRect.top());
+        break;
+    case DOCK_RIGHT:
+        p = QPoint(dockRect.left() - width() - dockSpacing, dockRect.top());
+        break;
+    default:
+        Q_UNREACHABLE_IMPL();
+    }
+
+    initAnchoredCornor();
+    move(p);
+}
+
+void WindowedFrame::onHideMenu()
+{
+    if (m_menuWorker.get() && !isVisible())
+        m_menuWorker.get()->onHideMenu();
+}
+
 void WindowedFrame:: paintEvent(QPaintEvent *e)
 {
     DBlurEffectWidget::paintEvent(e);
