@@ -1,47 +1,32 @@
-#include <gtest/gtest.h>
+#include "applistarea.h"
 
 #include <QApplication>
 #include <QWheelEvent>
 
-#include "applistarea.h"
-
+#include <gtest/gtest.h>
 
 class Tst_Applistarea : public testing::Test
-{
-public:
-    void SetUp() override
-    {
-        widget = new AppListArea;
-    }
-
-    void TearDown() override
-    {
-        if (widget) {
-            delete widget;
-            widget = nullptr;
-        }
-    }
-
-public:
-    AppListArea* widget = nullptr;
-};
+{};
 
 TEST_F(Tst_Applistarea, appListArea_test)
 {
-    QWidget *view = new QWidget;
-    widget->addWidget(view);
-
+    AppListArea area;
     QWheelEvent event(QPointF(0, 0), 0, Qt::MiddleButton, Qt::ControlModifier);
-    QApplication::sendEvent(widget, &event);
+    QApplication::sendEvent(&area, &event);
 
     QEvent event1(QEvent::Enter);
-    QApplication::sendEvent(widget, &event1);
+    QApplication::sendEvent(&area, &event1);
 
     QMouseEvent event2(QEvent::MouseButtonPress, QPointF(0, 0), QPointF(0, 1), QPointF(1, 1), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier, Qt::MouseEventSynthesizedByQt);
-    QApplication::sendEvent(widget, &event2);
+    QApplication::sendEvent(&area, &event2);
 
     QMouseEvent event3(QEvent::MouseButtonRelease, QPointF(0, 0), QPointF(0, 1), QPointF(1, 1), Qt::LeftButton, Qt::LeftButton, Qt::NoModifier, Qt::MouseEventSynthesizedByQt);
-    QApplication::sendEvent(widget, &event3);
+    QApplication::sendEvent(&area, &event3);
+
+    QWheelEvent wheelEvent(QPointF(0, 0), 10, Qt::MiddleButton, Qt::ControlModifier);
+    QApplication::sendEvent(&area, &wheelEvent);
+
+    QWheelEvent wheelEvent2(QPointF(0, 0), -10, Qt::MiddleButton, Qt::ControlModifier);
+    QApplication::sendEvent(&area, &wheelEvent2);
 
 }
-
